@@ -47,7 +47,7 @@ class Sora():
             )
         elif method.upper() == "POST":
             response = requests.post(url,
-                data=json.dumps(params),
+                data=json.dumps(params) if params else None,
                 headers={
                     "authorization": f"Bearer {self._config['api_key']}",
                 },
